@@ -1,6 +1,6 @@
 /* 
     SuperCat - The Super Cat Colorizer
-    Copyright (C) 2007 - Thomas G. Anderson
+    Copyright (C) 2007-2008 - Thomas G. Anderson
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ struct spc_s {
     char   *string;  /* string for strchr, strstr */
     char   *htmrgb;  /* html color codes RGB */
     int     number;  /* 1-9, 0:all */
-    char    htmlen;  /* length of htmrgb string */
+    size_t  htmlen;  /* length of htmrgb string */
     char    aryidx;  /* array index 1-255, 0=default */
     char    colour;  /* enum */
     char    attrib;  /* -, b, i, u */
@@ -52,6 +52,7 @@ char *inp_file = 0;
 int   inp_lineno = 0;
 char *typ_suffix = 0;
 
+void
 help ()
 {
     puts ("usage: spc [OPTIONS] [FILE]");
@@ -77,9 +78,9 @@ help ()
 void
 version ()
 {
-    printf ("spc (The SuperCat Colorizer) Version %s December 8, 2007", VERSION);
+    printf ("spc (The SuperCat Colorizer) Version %s February 15, 2008", VERSION);
     puts   ("");
-    puts   ("Copyright (C) 2007 - Thomas G. Anderson");
+    puts   ("Copyright (C) 2007-2008 - Thomas G. Anderson");
     puts   ("This is free software; see the source for copying conditions.  There is NO");
     puts   ("warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.");
     exit   (0);
@@ -381,7 +382,6 @@ FILE *
 configure ()
 {
     FILE    *rc;
-    struct   stat status_buffer [1];
     char    *home, *temp;
 
     /*
@@ -399,6 +399,7 @@ configure ()
 
         if (!(rc = config_check (temp)))
             err_quit ("can't open config file %s", temp);
+        free (temp);
         return (rc);
     }
 
@@ -852,10 +853,8 @@ finalize_con ()
 {
     putchar (0x1B);
     putchar ('[');
-    putchar ('1');
+    putchar ('0');
     putchar (';');
-    putchar ('3');
-    putchar ('7');
     putchar ('m');
 }
 
